@@ -81,6 +81,8 @@ HEADER__allow_origin = "Access-Control-Allow-Origin"
 HEADER__allow_methods = "Access-Control-Allow-Methods"
 HEADER__real_ip = "X-Real-IP"
 
+ENV__allow_cors = "ALLOW_CORS"
+
 BOOL__allowed = {
     "True": True,
     "False": False,
@@ -125,10 +127,13 @@ class BaseJAAQLController:
     internal_sentinel = False
     base_url = None
 
+    allow_cors = False
+
     def __init__(self, model: JAAQLModel, is_prod: bool, base_url: str, do_profiling: bool = False):
         super().__init__()
         BaseJAAQLController.base_url = base_url
         self.app = Flask(__name__, instance_relative_config=True)
+        BaseJAAQLController.allow_cors = os.environ.get(ENV__allow_cors, str(False)).lower().strip() == "true"
         self.json_serializer = JAAQLJSONProvider(self.app)
         self.app.config[FLASK__json_sort_keys] = False
         self.app.config[FLASK__max_content_length] = 1024 * 1024 * 2  # 2 MB
@@ -379,9 +384,10 @@ class BaseJAAQLController:
 
     @staticmethod
     def _cors(resp):
-        resp.headers.add(HEADER__allow_origin, CORS__WILDCARD)
-        resp.headers.add(HEADER__allow_headers, CORS__WILDCARD)
-        resp.headers.add(HEADER__allow_methods, CORS__WILDCARD)
+        if BaseJAAQLController.allow_cors:
+            resp.headers.add(HEADER__allow_origin, CORS__WILDCARD)
+            resp.headers.add(HEADER__allow_headers, CORS__WILDCARD)
+            resp.headers.add(HEADER__allow_methods, CORS__WILDCARD)
         return resp
 
     def log_safe_dump_recursive(self, data):
@@ -437,8 +443,9 @@ class BaseJAAQLController:
             for method in cur_documentation.methods:
                 methods.append(method.method)
 
-        methods.append(REST__OPTIONS)
-        swagger_documentation = documentation_as_lists[0]
+        if BaseJAAQLController.allow_cors:
+            methods.append(REST__OPTIONS)
+            swagger_documentation = documentation_as_lists[0]
 
         def wrap_func(view_func):
             @wraps(view_func)
@@ -629,10 +636,8 @@ class BaseJAAQLController:
                     resp = Response(resp, mimetype=jaaql_resp.response_type, status=jaaql_resp.response_code)
 
                 self._cors(resp)
-                self.perform_profile(request_id, "Jsonify")
 
-                # if not BaseJAAQLController.is_options():
-                #     print("Total time taken: " + str(time_delta_ms(start_time, datetime.now())) + "ms")
+                self.perform_profile(request_id, "Jsonify")
 
                 return resp
 
